# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.1.2]:

Use SSL and list of CAs from 'certifi' to verify websocket (wss) connections. 
On MacOS in particular, connection failed with the following error:
"ssl.SSLCertVerificationError: [SSL: CERTIFICATE_VERIFY_FAILED] certificate verify failed: unable to get local issuer certificate"

## [0.1.1]:

Add __init__.py files in submodules.

## [0.1.0]:

Beta release

## [0.0.1]:

initial commit

### Added

### Changed

### Fixed
